import { ApolloError, DocumentNode, QueryResult } from '@apollo/client';
/**
 * @see https://package.elm-lang.org/packages/krisajenkins/remotedata/latest/
 */
export declare type RemoteData<D> = Initialized | Pending | Failure | Success<D>;
export interface Initialized {
    readonly tag: 'Initialized';
}
export interface Pending {
    readonly tag: 'Pending';
}
export interface Failure {
    readonly tag: 'Failure';
    error: ApolloError;
}
export interface Success<A> {
    readonly tag: 'Success';
    data: A;
}
declare type QueryResultWithRemoteData<T> = QueryResult & {
    _rd: RemoteData<T>;
};
/**
 * @description Maps a `useQuery` QueryResult to the appropriate RemoteData discriminant
 * @param d DocumentNode
 * @returns Everything from `QueryResult` with an accompanying `_rd` property wth the RemoteData object
 */
export declare const useQueryRd: <T>(d: DocumentNode) => QueryResultWithRemoteData<T>;
export {};
//# sourceMappingURL=index.d.ts.map